@@ -1,7 +1,7 @@
-from p_connector_dfg import privacyPreserving, Utilities
+from p_connector_dfg import privacyPreserving, Utilities, Crypto
 
 __name__ = 'p_connector_dfg'
-__version__ = '0.0.10'
+__version__ = '0.0.11'
 __doc__ = "Privacy-preserving Process Discovery Using Connector Method"
 __author__ = 'Majid Rafiei'
 __author_email__ = 'majid.rafiei@pads.rwth-aachen.de'
